@@ -4,15 +4,6 @@ pyABC
 
 ABC algorithms for likelihood-free Bayesian parameter inference and model
 selection.
-
-.. note::
-    pyABC allows to parallelize the sampling process via various samplers.
-    If you want to also parallelize single model simulations, be careful that
-    both levels of parallelization work together well.
-    In particular, if the environment variable OMP_NUM_THREADS is not set,
-    pyABC sets it to a default of 1. For multi-processed sampling (the
-    default at least on linux systems), the flag PYABC_NUM_PROCS can be used to
-    determine on how many jobs to parallelize the sampling.
 """
 
 import logging
