@@ -6,7 +6,7 @@ import numpy as np
 import pandas as pd
 from sklearn.base import BaseEstimator
 
-from ..cv.bootstrap import calc_cv
+from ..cv import calc_cv
 from ..parameters import Parameter
 from .exceptions import NotEnoughParticles
 from .predict_population_size import predict_population_size
