@@ -8,12 +8,12 @@ MultivariateNormalTransition(), or to replace it by a GridSearchCV() to
 automatically find a visually good level of smoothness.
 """
 
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
 import pandas as pd
 
-from ..transition import MultivariateNormalTransition
 from ..storage import History
+from ..transition import MultivariateNormalTransition
 from .util import format_plot_matrix
 
 
@@ -76,10 +76,22 @@ def kde_1d(df, w, x, xmin=None, xmax=None, numx=50, kde=None):
 
 
 def plot_kde_1d_highlevel(
-        history: History, x: str, m: int = 0, t: int = None,
-        xmin=None, xmax=None, numx=50, ax=None,
-        size=None, title: str = None, refval=None, refval_color='C1',
-        kde=None, xname: str = None, **kwargs):
+    history: History,
+    x: str,
+    m: int = 0,
+    t: int = None,
+    xmin=None,
+    xmax=None,
+    numx=50,
+    ax=None,
+    size=None,
+    title: str = None,
+    refval=None,
+    refval_color='C1',
+    kde=None,
+    xname: str = None,
+    **kwargs,
+):
     """
     Plot 1d kernel density estimate of parameter samples.
 
@@ -130,14 +142,40 @@ def plot_kde_1d_highlevel(
     """
     df, w = history.get_distribution(m=m, t=t)
 
-    return plot_kde_1d(df, w, x, xmin, xmax, numx, ax, size, title, refval,
-                       refval_color, kde, xname, **kwargs)
+    return plot_kde_1d(
+        df,
+        w,
+        x,
+        xmin,
+        xmax,
+        numx,
+        ax,
+        size,
+        title,
+        refval,
+        refval_color,
+        kde,
+        xname,
+        **kwargs,
+    )
 
 
 def plot_kde_1d(
-        df, w, x, xmin=None, xmax=None, numx=50, ax=None, size=None,
-        title: str = None, refval=None, refval_color='C1', kde=None,
-        xname: str = None, **kwargs):
+    df,
+    w,
+    x,
+    xmin=None,
+    xmax=None,
+    numx=50,
+    ax=None,
+    size=None,
+    title: str = None,
+    refval=None,
+    refval_color='C1',
+    kde=None,
+    xname: str = None,
+    **kwargs,
+):
     """
     Lowlevel interface for plot_kde_1d_highlevel (see there for the remaining
     parameters).
@@ -154,7 +192,7 @@ def plot_kde_1d(
     ax: matplotlib axis
         Axis of the plot.
     """
-    x_vals, pdf = kde_1d(df, w, x, xmin=xmin, xmax=xmax,  numx=numx, kde=kde)
+    x_vals, pdf = kde_1d(df, w, x, xmin=xmin, xmax=xmax, numx=numx, kde=kde)
     if xname is None:
         xname = x
     if ax is None:
@@ -177,8 +215,19 @@ def plot_kde_1d(
     return ax
 
 
-def kde_2d(df, w, x, y, xmin=None, xmax=None, ymin=None, ymax=None,
-           numx=50, numy=50, kde=None):
+def kde_2d(
+    df,
+    w,
+    x,
+    y,
+    xmin=None,
+    xmax=None,
+    ymin=None,
+    ymax=None,
+    numx=50,
+    numy=50,
+    kde=None,
+):
     """
     Calculates a 2 dimensional histogram from a Dataframe and weights.
 
@@ -246,8 +295,9 @@ def kde_2d(df, w, x, y, xmin=None, xmax=None, ymin=None, ymax=None,
         ymin = df[y].min()
     if ymax is None:
         ymax = df[y].max()
-    X, Y = np.meshgrid(np.linspace(xmin, xmax, num=numx),
-                       np.linspace(ymin, ymax, num=numy))
+    X, Y = np.meshgrid(
+        np.linspace(xmin, xmax, num=numx), np.linspace(ymin, ymax, num=numy)
+    )
     test = pd.DataFrame({x: X.flatten(), y: Y.flatten()})
     pdf = kde.pdf(test)
     PDF = pdf.reshape(X.shape)
@@ -255,12 +305,28 @@ def kde_2d(df, w, x, y, xmin=None, xmax=None, ymin=None, ymax=None,
 
 
 def plot_kde_2d_highlevel(
-        history: History, x: str, y: str, m: int = 0, t: int = None,
-        xmin: float = None, xmax: float = None, ymin: float = None,
-        ymax: float = None, numx: int = 50, numy: int = 50, ax=None,
-        size=None, colorbar=True, title: str = None, refval=None,
-        refval_color='C1', kde=None, xname: str = None, yname: str = None,
-        **kwargs):
+    history: History,
+    x: str,
+    y: str,
+    m: int = 0,
+    t: int = None,
+    xmin: float = None,
+    xmax: float = None,
+    ymin: float = None,
+    ymax: float = None,
+    numx: int = 50,
+    numy: int = 50,
+    ax=None,
+    size=None,
+    colorbar=True,
+    title: str = None,
+    refval=None,
+    refval_color='C1',
+    kde=None,
+    xname: str = None,
+    yname: str = None,
+    **kwargs,
+):
     """
     Plot 2d kernel density estimate of parameter samples.
 
@@ -327,14 +393,51 @@ def plot_kde_2d_highlevel(
     df, w = history.get_distribution(m=m, t=t)
 
     return plot_kde_2d(
-        df, w, x, y, xmin, xmax, ymin, ymax, numx, numy, ax, size, colorbar,
-        title, refval, refval_color, kde, xname, yname, **kwargs)
+        df,
+        w,
+        x,
+        y,
+        xmin,
+        xmax,
+        ymin,
+        ymax,
+        numx,
+        numy,
+        ax,
+        size,
+        colorbar,
+        title,
+        refval,
+        refval_color,
+        kde,
+        xname,
+        yname,
+        **kwargs,
+    )
 
 
-def plot_kde_2d(df, w, x, y, xmin=None, xmax=None, ymin=None, ymax=None,
-                numx=50, numy=50, ax=None, size=None, colorbar=True,
-                title: str = None, refval=None, refval_color='C1', kde=None,
-                xname: str = None, yname: str = None, **kwargs):
+def plot_kde_2d(
+    df,
+    w,
+    x,
+    y,
+    xmin=None,
+    xmax=None,
+    ymin=None,
+    ymax=None,
+    numx=50,
+    numy=50,
+    ax=None,
+    size=None,
+    colorbar=True,
+    title: str = None,
+    refval=None,
+    refval_color='C1',
+    kde=None,
+    xname: str = None,
+    yname: str = None,
+    **kwargs,
+):
     """
     Plot a 2d kernel density estimate of parameter samples.
 
@@ -352,10 +455,19 @@ def plot_kde_2d(df, w, x, y, xmin=None, xmax=None, ymin=None, ymax=None,
         Axis of the plot.
 
     """
-    X, Y, PDF = kde_2d(df, w, x, y,
-                       xmin=xmin, xmax=xmax,
-                       ymin=ymin, ymax=ymax, numx=numx, numy=numy,
-                       kde=kde)
+    X, Y, PDF = kde_2d(
+        df,
+        w,
+        x,
+        y,
+        xmin=xmin,
+        xmax=xmax,
+        ymin=ymin,
+        ymax=ymax,
+        numx=numx,
+        numy=numy,
+        kde=kde,
+    )
     if xname is None:
         xname = x
     if yname is None:
@@ -381,10 +493,20 @@ def plot_kde_2d(df, w, x, y, xmin=None, xmax=None, ymin=None, ymax=None,
 
 
 def plot_kde_matrix_highlevel(
-        history, m: int = 0, t: int = None, limits=None,
-        colorbar: bool = True, height: float = 2.5,
-        numx: int = 50, numy: int = 50, refval=None, refval_color='C1',
-        kde=None, names: dict = None, arr_ax=None):
+    history,
+    m: int = 0,
+    t: int = None,
+    limits=None,
+    colorbar: bool = True,
+    height: float = 2.5,
+    numx: int = 50,
+    numy: int = 50,
+    refval=None,
+    refval_color='C1',
+    kde=None,
+    names: dict = None,
+    arr_ax=None,
+):
     """
     Plot a KDE matrix for 1- and 2-dim marginals of the parameter samples.
 
@@ -431,13 +553,35 @@ def plot_kde_matrix_highlevel(
     df, w = history.get_distribution(m=m, t=t)
 
     return plot_kde_matrix(
-        df, w, limits, colorbar, height, numx, numy, refval, refval_color,
-        kde, names, arr_ax)
+        df,
+        w,
+        limits,
+        colorbar,
+        height,
+        numx,
+        numy,
+        refval,
+        refval_color,
+        kde,
+        names,
+        arr_ax,
+    )
 
 
-def plot_kde_matrix(df, w, limits=None, colorbar=True, height=2.5,
-                    numx=50, numy=50, refval=None, refval_color='C1',
-                    kde=None, names: dict = None, arr_ax=None):
+def plot_kde_matrix(
+    df,
+    w,
+    limits=None,
+    colorbar=True,
+    height=2.5,
+    numx=50,
+    numy=50,
+    refval=None,
+    refval_color='C1',
+    kde=None,
+    names: dict = None,
+    arr_ax=None,
+):
     """
     Plot a KDE matrix for 1- and 2-dim marginals of the parameter samples.
 
@@ -462,9 +606,13 @@ def plot_kde_matrix(df, w, limits=None, colorbar=True, height=2.5,
     if names is None:
         names = {key: key for key in par_ids}
     if arr_ax is None:
-        fig, arr_ax = plt.subplots(nrows=n_par, ncols=n_par,
-                                   sharex=False, sharey=False,
-                                   figsize=(height * n_par, height * n_par))
+        fig, arr_ax = plt.subplots(
+            nrows=n_par,
+            ncols=n_par,
+            sharex=False,
+            sharey=False,
+            figsize=(height * n_par, height * n_par),
+        )
     else:
         fig = arr_ax[0, 0].get_figure()
 
@@ -474,16 +622,26 @@ def plot_kde_matrix(df, w, limits=None, colorbar=True, height=2.5,
 
     def hist_2d(x, y, ax):
         df = pd.concat((x, y), axis=1)
-        plot_kde_2d(df, w,
-                    x.name, y.name,
-                    xmin=limits.get(x.name, default)[0],
-                    xmax=limits.get(x.name, default)[1],
-                    ymin=limits.get(y.name, default)[0],
-                    ymax=limits.get(y.name, default)[1],
-                    numx=numx, numy=numy,
-                    ax=ax, title=None, colorbar=colorbar,
-                    refval=refval, refval_color=refval_color,
-                    kde=kde, xname=names[x.name], yname=names[y.name])
+        plot_kde_2d(
+            df,
+            w,
+            x.name,
+            y.name,
+            xmin=limits.get(x.name, default)[0],
+            xmax=limits.get(x.name, default)[1],
+            ymin=limits.get(y.name, default)[0],
+            ymax=limits.get(y.name, default)[1],
+            numx=numx,
+            numy=numy,
+            ax=ax,
+            title=None,
+            colorbar=colorbar,
+            refval=refval,
+            refval_color=refval_color,
+            kde=kde,
+            xname=names[x.name],
+            yname=names[y.name],
+        )
 
     def scatter(x, y, ax):
         alpha = w / w.max()
@@ -497,12 +655,19 @@ def plot_kde_matrix(df, w, limits=None, colorbar=True, height=2.5,
 
     def hist_1d(x, ax):
         df = pd.concat((x,), axis=1)
-        plot_kde_1d(df, w, x.name,
-                    xmin=limits.get(x.name, default)[0],
-                    xmax=limits.get(x.name, default)[1],
-                    numx=numx,
-                    ax=ax, refval=refval, refval_color=refval_color,
-                    kde=kde, xname=x.name)
+        plot_kde_1d(
+            df,
+            w,
+            x.name,
+            xmin=limits.get(x.name, default)[0],
+            xmax=limits.get(x.name, default)[1],
+            numx=numx,
+            ax=ax,
+            refval=refval,
+            refval_color=refval_color,
+            kde=kde,
+            xname=x.name,
+        )
 
     # fill all subplots
     for i in range(0, n_par):
